@@ -25,11 +25,12 @@
 #'   matrix of the parameter estimates is used.
 #' @param accuracy numeric; accuracy with which to report p values, with p
 #'   values below this value displayed as `"< accuracy"`.
+#' @param digits numeric; the number of significant digits to be used.
 #' @param stars logical; should significance stars be added to the output?
 #'
 #' @export
 #' @rdname overview
-#' @importFrom dplyr %>% select
+#' @importFrom dplyr select bind_rows
 #' @importFrom tibble rownames_to_column as_tibble add_column
 #' @importFrom tidyselect matches
 #' @importFrom rlang set_names .data
@@ -52,53 +53,62 @@
 `overview.gam` <- function(model, parametric = TRUE, random_effects = TRUE,
                            dispersion = NULL, frequentist = FALSE,
                            accuracy = 0.001,
+                           digits = 3,
                            stars = FALSE,
                            ...) {
   smry <- summary(model,
     dispersion = dispersion, re.test = random_effects,
     freq = frequentist
   )
-  nms <- c("term", "type", "k", "edf", "statistic", "p.value")
+  nms <- c("term", "type", "k", "edf", "ref.edf", "statistic", "p.value")
 
   # smooth terms
   types <- vapply(model$smooth, smooth_type, character(1))
   dfs <- vapply(model$smooth, basis_size, double(1))
-  out <- as.data.frame(smry$s.table) %>%
-    rownames_to_column() %>%
-    as_tibble() %>%
-    select(!matches("Ref.df")) %>%
-    add_column(type = types, k = dfs, .after = 1L)
+  out <- as.data.frame(smry$s.table) |>
+    rownames_to_column() |>
+    as_tibble() |>
+    # select(!matches("Ref.df")) |>
+    add_column(type = types, k = dfs, .after = 1L) |>
+    set_names(nms)
 
   # parametric terms
   para <- NULL
-  if (isTRUE(parametric) && !is.null(smry$pTerms.table)) {
-    nr <- nrow(smry$pTerms.table)
-    para <- as.data.frame(smry$pTerms.table) %>%
-      rownames_to_column() %>%
-      as_tibble() %>%
-      rename(edf = "df") %>%
-      add_column(
-        type = rep("parametric", nr), k = rep(NA_real_, nr),
-        .after = 1L
-      )
+  if (isTRUE(parametric) && !is.null(smry$p.table)) {
+    nr <- nrow(smry$p.table)
+    para_nms <- gsub("\\((Intercept)\\)", "\\1", x = rownames(smry$p.table))
+    para <- data.frame(
+      term = para_nms,
+      type = rep("parametric", nr),
+      k    = rep(NA_real_, nr),
+      edf  = c(1, smry$pTerms.df),
+      ref.edf = c(1, smry$pTerms.df),
+      statistic = smry$p.t,
+      p.value = smry$p.pv
+    ) |>
+    as_tibble()
     out <- bind_rows(para, out)
   }
   out <- set_names(out, nms)
 
   if (stars) {
-    sstars <- symnum(out$p.value,
+    sstars <- symnum(
+      out$p.value,
       corr = FALSE, na = FALSE,
       cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
       symbols = c("***", "**", "*", ".", " ")
     )
     out <- mutate(out,
       # p = .data$p.value,
-      p.value = format.pval(.data$p.value, eps = accuracy),
+      p.value = format.pval(.data$p.value, eps = accuracy, digits = digits),
       stars = sstars
     ) # not sure why as.character(sstars) is wrong here "***"
     attr(out, "legend") <- attr(sstars, "legend")
   } else {
-    out <- mutate(out, p.value = format.pval(.data$p.value, eps = accuracy))
+    out <- mutate(
+      out,
+      p.value = format.pval(.data$p.value, eps = accuracy, digits = digits)
+    )
   }
 
   class(out) <- append(class(out), values = "overview", after = 0)
