@@ -70,6 +70,12 @@
   object[["dim"]]
 }
 
+#' @export
+`smooth_dim.default` <- function(object) {
+  check_is_mgcv_smooth(object)
+  object[["dim"]]
+}
+
 `select_terms` <- function(object, terms) {
   TERMS <- unlist(smooth_terms(object))
   terms <- if (missing(terms)) {
@@ -202,7 +208,10 @@
 #' @export
 #' @rdname is_mgcv_smooth
 `is_mgcv_smooth` <- function(smooth) {
-  inherits(smooth, "mgcv.smooth")
+  inherits(
+    smooth,
+    what = c("mgcv.smooth", "tensor.smooth", "tprs.smooth")
+  )
 }
 
 #' @export
@@ -1981,7 +1990,7 @@ reclass_scam_smooth <- function(smooth) {
 }
 
 #### helper functions for Tweedie
-# this converts from theta to power parameter `p`` given `a` and `b`
+# this converts from theta to power parameter `p` given `a` and `b`
 theta_2_power <- function(theta, a, b) {
   i <- theta > 0
   exp_theta_pos <- exp(-theta[i])
@@ -1994,10 +2003,15 @@ theta_2_power <- function(theta, a, b) {
 # extracts the `a` and `b` parameters of the model search over which the power
 # parameter is searched for
 get_tw_ab <- function(family) {
-  if (family_name(family) != "twlss") {
-    stop("'model' wasn't fitted with 'twlss()' family.", call. = FALSE)
+  ft <- family_type(family)
+  if (!ft %in% c("twlss", "tweedie")) {
+    stop("'model' wasn't fitted with a Tweedie family.", call. = FALSE)
+  }
+  rfun <- if (identical(ft, "twlss")) {
+    family$residuals
+  } else {
+    family$getTheta
   }
-  rfun <- family$residuals
   a <- get(".a", envir = environment(rfun))
   b <- get(".b", envir = environment(rfun))
   c(a, b)
@@ -2071,4 +2085,16 @@ multivariate_y <- function() {
 `is_soap_film` <- function(object) {
   check_is_mgcv_smooth(object)
   inherits(object, "soap.film")
-}
\ No newline at end of file
+}
+
+# does a smooth involve random effects
+`is_ranef_smooth` <- function(object) {
+  check_is_mgcv_smooth(object)
+  is_ranef <- is_re_smooth(object) ||
+    is_fs_smooth(object)
+  if (!is_ranef) {
+    sm_typ <- vapply(object$margin, smooth_type, character(1L))
+    is_ranef <- any(sm_typ == "Random effect")
+  }
+  is_ranef
+}
